implementation module ligrettoTOP

import ligretto
import iTasks

derive class iTask Player, Color, Hand, Card
instance toString Color where toString c = hd (gVisualizeText{|*|} AsLabel c)

/** view_card side_up card = html:
		creates @html equivalent to <td>...</td> element that can be used in a table row (<tr>...</tr>).
		It displays @card with the given @side_up.
*/
view_card :: SideUp Card -> HtmlTag
view_card side_up card
	= TdTag [StyleAttr (glue_style_atts [("text-align","center")
	                                    ,("background",""<+++color)
	                                    ,("padding","20px")
	                                    ,("color",if (color===Yellow) "black" "white")
	                                    ])]
	        [Text content]
where
	(color,content)	= case side_up of
						Front = (card.front, toString card.nr)
						Back  = (card.back,  "-")

glue_style_atts atts = foldr (\(a,b) c -> a<+++":"<+++b<+++";"<+++c) "" atts

/** view_row row = html:
		creates @html equivalent to <table>...</table> that displays the cards in the row as well
		as their number.
*/
view_row :: Row -> HtmlTag
view_row row
	= TableTag []
	           [TrTag [] [TdTag [] [Text (if (i==1) "row" "")] \\ i <- [1..length row]]
	           ,TrTag [] [TdTag [] [Text (toString i)]         \\ i <- [1..length row]]
	           ,TrTag [] [view_card Front card                 \\ card <- row]
	           ]


/** view_ligretto pile = html:
		creates @html that renders the ligretto @pile. Only the top card of @pile needs to be
		displayed, with the front side up.
*/
view_ligretto :: Pile -> HtmlTag
view_ligretto pile
	= TableTag []
	           [TrTag [] [TdTag [] [Text "ligretto"]]
	           ,if (isEmpty pile) 
	               (TrTag [] [TdTag [] [Text "empty!"]])
	               (TrTag [] [view_card Front (hd pile)])
	           ]

/** view_hand hand = html:
		creates @html that renders the top conceal (if any) and top discard (if any) card of
		@hand. The top conceal card is displayed with the back side up, and the top discard card
		is displayed with the front side up.
*/
view_hand :: Hand -> HtmlTag
view_hand hand
	= Text "You have not yet implemented 'view_hand'"

/** play_ligretto:
		is the main task that you need to create. With this task the user invites friends to play a game
		of Ligretto and plays it. 
*/
play_ligretto :: Task Color
play_ligretto
	= viewInformation "You have not yet implemented 'play_ligretto'" [] Red
